package
Version:
v0.0.0-...-287d1b1
Opens a new window with list of versions in this module.
Published: Sep 27, 2024
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
server serves HTTP requests for our banking service
NewServer creates a new HTTP server and setup routing
start runs the HTTP server on a specific address
type UserResponse struct {
Username string `json:"username"`
FullName string `json:"full_name"`
Email string `json:"email"`
PasswordChangedAt time.Time `json:"password_changed_at"`
CreatedAt time.Time `json:"created_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.